Learn R Programming

Rcrawler (version 0.1.1)

getsimHash: Calculate SimHash fingerprint in R

Description

A function that take a _charachter_ as input, and generate it's simhash.

Usage

getsimHash(string, hashbits)

Arguments

string

character, the content to hash.

hashbits

numeric, specify the hash bits 64 or 128

Value

return the simhash as a nmeric value

Details

This funcion call an external java class

Examples

Run this code
# NOT RUN {
text<-"R is a free software environment for statistical computing and graphics.
      It compiles and runs on a wide variety of UNIX platforms, Windows and MacOS"
fingerprint<-getsimHash(text,64)


# }

Run the code above in your browser using DataLab