# NOT RUN {
text<-"R is a free software environment for statistical computing and graphics.
It compiles and runs on a wide variety of UNIX platforms, Windows and MacOS"
fingerprint<-getsimHash(text,64)
# }
Run the code above in your browser using DataLab